local MAJOR, MINOR = "LibUI-0.1", 4
local LibUI, oldminor = LibStub:NewLibrary(MAJOR, MINOR)
if not LibUI then return end	--the same or newer version of this lib is already loaded into memory 

LibUI.defaultFont = "ZoFontGame"

function LibUI:CreateTopLevelWindow(name, parent, dimensions, anchors, offsets, isHidden)
	if name == nil or name == "" then return end
	if parent == nil or parent == "" then parent = GuiRoot end
	if #dimensions ~= 2 then return end
	if #anchors ~= 2 then return end
	if #offsets ~= 2 then return end
	isHidden = isHidden or false

	local topLevelWindow = WINDOW_MANAGER:CreateTopLevelWindow(name)
	topLevelWindow:SetDimensions(dimensions[1], dimensions[2])
	topLevelWindow:SetAnchor(anchors[1], parent, anchors[2], offsets[1], offsets[2])
	topLevelWindow:SetHidden(isHidden)
	return topLevelWindow
end

function LibUI:CreateControl(name, parent, dimensions, anchors, offsets, isHidden)
	if name == nil or name == "" then return end
	if parent == nil or parent == "" then parent = GuiRoot end
	if #dimensions ~= 2 then return end
	if #anchors ~= 2 then return end
	if #offsets ~= 2 then return end
	isHidden = isHidden or false
	
	local control = WINDOW_MANAGER:CreateControl(name, parent, CT_CONTROL)
	control:SetDimensions(dimensions[1], dimensions[2])
	control:SetAnchor(anchors[1], parent, anchors[2], offsets[1], offsets[2])
	control:SetHidden(isHidden)
	return control
end

function LibUI:CreateBackdropFromVirtual(name, parent, skin, isHidden)
	if parent == nil or parent == "" then return end
	if skin == nil or skin == "" then skin = "ZO_DefaultBackdrop" end
	isHidden = isHidden or false
	
	local backdrop = WINDOW_MANAGER:CreateControlFromVirtual(name, parent, skin)
	backdrop:SetAnchorFill(parent)
	return backdrop
end

function LibUI:CreateBackdrop(name, parent, dimensions, anchors, offsets, centerColor, edgeColor, isHidden)
	if name == nil or name == "" then return end
	if parent == nil or parent == "" then parent = GuiRoot end
	if #dimensions ~= 2 then return end
	if #anchors ~= 2 then return end
	if #offsets ~= 2 then return end
	if centerColor == nil or #centerColor ~= 4 then centerColor = {1, 1, 1, 1} end
	if edgeColor == nil or #edgeColor ~= 4 then edgeColor = {1, 1, 1, 1} end
	isHidden = isHidden or false

	local backdrop = WINDOW_MANAGER:CreateControl(name, parent, CT_BACKDROP)
	backdrop:SetDimensions(dimensions[1] , dimensions[2])
	backdrop:SetAnchor(anchors[1], parent , anchors[2] , offsets[1] , offsets[2] )
	backdrop:SetCenterColor(centerColor[1] , centerColor[2] , centerColor[3] , centerColor[4] )
	backdrop:SetEdgeColor(edgeColor[1] , edgeColor[2] , edgeColor[3] , edgeColor[4])
	backdrop:SetEdgeTexture("", 8 ,1 ,2)
	backdrop:SetHidden(isHidden)
	return backdrop
end

function LibUI:CreateSlider(name, parent, dimensions, anchors, offsets, min, max, isHidden)
	if name == nil or name == "" then return end
	if parent == nil or parent == "" then parent = GuiRoot end
	if #dimensions ~= 2 then return end
	if #anchors ~= 2 then return end
	if #offsets ~= 2 then return end
	if font == nil or font == "" then font = LibUI.defaultFont end
	if orientation == nil or "" then orientation = 0 end
	if min == nil or min == "" then min = 1 end
	if max == nil or max == "" then max = 10 end
	isHidden = isHidden or false
	
	local slider = WINDOW_MANAGER:CreateControl(name, parent, CT_SLIDER)
	local tex = "/esoui/art/miscellaneous/scrollbox_elevator.dds"
	slider:SetDimensions(dimensions[1], dimensions[2] )
	slider:SetAnchor(anchors[1], parent, anchors[2], offsets[1], offsets[2])
    slider:SetThumbTexture(tex, tex, tex, 5, 5, 0, 0, 1, 1)
	slider:SetMinMax(min, max)
	slider:SetValue(min)
    slider:SetValueStep(1)
	slider:SetHidden(isHidden)
	slider:SetMouseEnabled(true)
	return slider
end

function LibUI:CreateLabel(name, parent, dimensions, anchors, offsets, font, color, align, text, isHidden)
	if name == nil or name == "" then return end
	if parent == nil or parent == "" then parent = GuiRoot end
	if #dimensions ~= 2 then return end
	if #anchors ~= 2 then return end
	if #offsets ~= 2 then return end
	if font == nil or font == "" then font = LibUI.defaultFont end
	if color == nil or #color ~= 4 then color = {1, 1, 1, 1} end
	if align == nil or #align ~= 2 then align = {1, 1} end
	isHidden = isHidden or false
	
	local label = WINDOW_MANAGER:CreateControl(name, parent, CT_LABEL)
	label:SetDimensions(dimensions[1], dimensions[2] )
	label:SetAnchor(anchors[1], parent, anchors[2], offsets[1], offsets[2])
	label:SetFont(font)
	label:SetColor(color[1], color[2], color[3], color[4])
	label:SetHorizontalAlignment(align[1])
	label:SetVerticalAlignment(align[2])
	label:SetText(text)
	label:SetHidden(isHidden)
	
	return label
end

function LibUI:CreateButton(name, parent, dimensions, anchors, offsets, state, font, align, normal, pressed, mouseover, isHidden)
	if name == nil or name == "" then return end
	if parent == nil or parent == "" then parent = GuiRoot end
	if #dimensions ~= 2 then return end
	if #anchors ~= 2 then return end
	if #offsets ~= 2 then return end
	state = state or BSTATE_NORMAL
	if font == nil or font == "" then font = LibUI.defaultFont end
	if align == nil or #align ~= 2 then align = {1, 1} end
	if normal == nil or #normal ~= 4 then normal = {1, 1, 1, 1} end
	if pressed == nil or #pressed ~= 4 then pressed = {1, 1, 0, 1} end
	if mouseover == nil or #mouseover ~= 4 then mouseover = {1, 1, 0, 1} end
	isHidden = isHidden or false
	
	-- Create the backdrop
	local button = WINDOW_MANAGER:CreateControl(name, parent, CT_BUTTON) 
	button:SetDimensions(dimensions[1], dimensions[2])
	button:SetAnchor(anchors[1], parent, anchors[2], offsets[1], offsets[2])
	button:SetFont(font)
	button:SetNormalFontColor(normal[1], normal[2], normal[3], normal[4])
	button:SetPressedFontColor(pressed[1], pressed[2], pressed[3], pressed[4])
	button:SetMouseOverFontColor(mouseover[1], mouseover[2], mouseover[3], mouseover[4])
	button:SetHorizontalAlignment(align[1])
	button:SetVerticalAlignment(align[2])
	button:SetHidden(isHidden)
	return button
end

function LibUI:CreateTextBuffer(name, parent, dimensions, anchors, offsets, font, hAlign, isHidden)
	if name == nil or name == "" then return end
	if parent == nil or parent == "" then parent = GuiRoot end
	if #dimensions ~= 2 then return end
	if #anchors ~= 2 then return end
	if #offsets ~= 2 then return end
	if font == nil or font == "" then font = LibUI.defaultFont end
	if hAlign == nil then hAlign = 1 end
	if normal == nil or #normal ~= 4 then normal = {1, 1, 1, 1} end
	isHidden = isHidden or false
	
	-- Create the backdrop
	local textBuffer = WINDOW_MANAGER:CreateControl(name, parent, CT_TEXTBUFFER) 
	textBuffer:SetDimensions(dimensions[1], dimensions[2])
	textBuffer:SetAnchor(anchors[1], parent, anchors[2], offsets[3], offsets[4])
	textBuffer:SetFont(font)
	textBuffer:SetHorizontalAlignment(hAlign)
	textBuffer:SetDrawLastEntryIfOutOfRoom(false)  --Looks shitty otherwise.
	textBuffer:SetHidden(isHidden)
	return textBuffer
end

function LibUI:CreateScroll(name, parent, dimensions, anchors, offsets, font, align, minMax, isHidden)
	if name == nil or name == "" then return end
	if parent == nil or parent == "" then parent = GuiRoot end
	if #dimensions ~= 2 then return end
	if #anchors ~= 2 then return end
	if #offsets ~= 2 then return end
	if font == nil or font == "" then font = LibUI.defaultFont end
	if align == nil or #align ~= 2 then align = {1, 1} end
	if #minMax ~= 2 then minMax = {1, 10} end
	if normal == nil or #normal ~= 4 then normal = {1, 1, 1, 1} end
	isHidden = isHidden or false
	
	-- Create the backdrop
	local scroll = WINDOW_MANAGER:CreateControl(name, parent, CT_SCROLL) 
	scroll:SetDimensions(dimensions[1], dimensions[2])
	scroll:SetAnchor(anchors[1], parent, anchors[2], offsets[1], offsets[2])
		--scroll:SetFont(font)
	--scroll:SetHorizontalAlignment(align[1])
	--scroll:SetVerticalAlignment(align[2])
	scroll:SetHorizontalScroll(1)
	scroll:SetScrollBounding(1)
	scroll:SetVerticalScroll(1)
	
	return textBuffer

end
