
local LAM = LibStub("LibAddonMenu-1.0")		
local LibUI = LibStub('LibUI-0.1')

if ( not LibUI ) then return end
if ( not LAM ) then return end

MFL.Config = {}

function MFL.Config.Initialize()
    MFL.Config.panel = LAM:CreateControlPanel("_MiniFriendList", "MiniFriendList")
	LAM:AddHeader(MFL.Config.panel, '_RANDO', 'by |c00ff00Rando|')
	
	LAM:AddHeader(MFL.Config.panel, '_OPTIONS', 'OPTIONS V' .. MFL.version )
	
	--Make the frame movable.
	LAM:AddCheckbox(MFL.Config.panel, '_FRAMEMOVABLE', 'Frame Movable', 'Should we allow the friend list frame to be movable?', function() 
			return MFL.savedVars.mainFrameMovable
		end, function() 
			MFL.Config.ToggleMainFrameMovable() 
			--Force an update.
			MFL.Update(true)
		end)
    
	--See offline players.
	LAM:AddCheckbox(MFL.Config.panel, '_SHOWOFFLINE', 'Show Offline', 'Should we show offline players?', function() 
			return MFL.savedVars.showOffline
		end, function() 
			MFL.Config.ToggleShowOffline() 
			--Force an update.
			MFL.Update(true)
		end)
    
	--Auto accept group invites from friends.
	LAM:AddCheckbox(MFL.Config.panel, '_AUTOACCEPT', 'Auto Accept Friendly Group Invites', 'Should we auto accept group invites from friends?', function() 
			return MFL.savedVars.autoAccept
		end, function() 
			MFL.Config.ToggleAutoAccept() 
		end)
	
	LAM:AddHeader(MFL.Config.panel, '_FRIEND_LIST_FRAME', 'Friend Frame Settings')
	--Change the list size.
    LAM:AddSlider(MFL.Config.panel, '_LISTSIZE', 'List Size', 'How many friends to show in list (ReloadUI)', 2, 35, 1, function() 
			return MFL.savedVars.listSize
		end, function(newSize) 
			MFL.savedVars.listSize = newSize 
			ReloadUI()
		end)
		
	--Change the list scale.
    LAM:AddSlider(MFL.Config.panel, '_MF_SCALE', 'Scale', 'Change the friend list scale by percentage.', 1, 200, 1, function() 
			return MFL.savedVars.mainFrameScale
		end, function(newScale) 
			MFL.savedVars.mainFrameScale = newScale 
			MFL.UI.MainFrame.top:SetScale(newScale / 100)
		end)
		
	--Change the list alpha.
    LAM:AddSlider(MFL.Config.panel, '_MF_ALPHA', 'Alpha', 'Change the friend list alpha by percentage.', 0, 100, 1, function() 
			return MFL.savedVars.mainFrameAlpha
		end, function(newAlpha) 
			MFL.savedVars.mainFrameAlpha = newAlpha 
			MFL.UI.MainFrame.top.backdrop:SetAlpha(newAlpha / 100)
		end)
		
	--Change the font.
	LAM:AddDropdown(MFL.Config.panel, "_FONT", "Font Style", "Choose the font style. (ReloadUI)", { "ZoFontAlert", "ZoFontAnnounce", "ZoFontAnnounceMedium", "ZoFontAnnounceMessage", "ZoFontAnnounceSmall", "ZoFontBookLetter", "ZoFontBookLetterTitle", "ZoFontBookNote", "ZoFontBookNoteTitle", "ZoFontBookPaper", "ZoFontBookPaperTitle", "ZoFontBookRubbing", "ZoFontBookRubbingTitle", "ZoFontBookScroll", "ZoFontBookSkin", "ZoFontBookTablet", "ZoFontBoss", "ZoFontCallout", "ZoFontChat", "ZoFontGame", "ZoFontHeader", "ZoFontKeybindStripDescription", "ZoFontTooltipTitle", "ZoFontWindowSubtitle", "ZoFontWindowTitle", "ZoFontWinH1", "ZoFontWinH2", "ZoFontWinT1" }, function() 
			return MFL.savedVars.mainFrameFont
		end, function(newFont)  
			MFL.savedVars.mainFrameFont = newFont
			ReloadUI()
		end)
		
	--Change the font.
	LAM:AddDropdown(MFL.Config.panel, "_MF_FONTALIGN", "Font Alignment", "Choose the font alignment.", {"LEFT", "RIGHT", "CENTER" }, function() 
			return MFL.savedVars.mainFrameFontAlign
		end, function(newAlign)  
			local align = nil
			if newAlign == "LEFT" then
				align = 0
			elseif newAlign == "RIGHT" then
				align = 2
			elseif newAlign == "CENTER" then
				align = 1
			end
			
			MFL.savedVars.mainFrameFontAlign = align
			--Change each button control label alignment.
			for i = 1, MFL.savedVars.listSize, 1 do
				MFL.UI.MainFrame.top.btnList[i]:GetLabelControl():SetHorizontalAlignment(align)
			end
		end)
		
	--Change the backdrop.
	LAM:AddDropdown(MFL.Config.panel, "_BACKDROP", "Backdrop Style", "Choose the backdrop style. (ReloadUI)", { "ZO_DefaultBackdrop", "ZO_ThinBackdrop", "ZO_InsetBackdrop", "ZO_InsetTexture", "ZO_CenterlessBackdrop"}, function() 
			return MFL.savedVars.skin
		end, function(newSkin)  
			MFL.savedVars.skin = newSkin
			ReloadUI()
		end)
end

function MFL.Config.ToggleShowOffline()
	MFL.savedVars.showOffline = not MFL.savedVars.showOffline
	MFL.UI.MainFrame.offsetIndex = 1
end

function MFL.Config.ToggleAutoAccept()
	MFL.savedVars.autoAccept = not MFL.savedVars.autoAccept
	if MFL.savedVars.autoAccept == true then
		EVENT_MANAGER:RegisterForEvent(MFL.name, EVENT_GROUP_INVITE_RECEIVED, MFL.OnGroupInvitation)
	else
		EVENT_MANAGER:UnregisterForEvent(MFL.name, EVENT_GROUP_INVITE_RECEIVED)
	end
end

function MFL.Config.ToggleMainFrameMovable()
	MFL.savedVars.mainFrameMovable = not MFL.savedVars.mainFrameMovable
	
	--If frame is movable, show the label.
	if MFL.savedVars.mainFrameMovable == true then
		MFL.UI.MainFrame.top.labelMoveMe:SetHidden(false)
	else
		MFL.UI.MainFrame.top.labelMoveMe:SetHidden(true)
	end
end


