
local LibUI = LibStub('LibUI-0.1')
if ( not LibUI ) then return end


MFL.UI.MainFrame               = {}
MFL.UI.MainFrame.name          = "_MainFrame"
MFL.UI.MainFrame.offsetIndex   = 1


function MFL.UI.MainFrame.Initialize()
	local mf = LibUI:CreateTopLevelWindow(MFL.name .. MFL.UI.MainFrame.name, GuiRoot, {700, 1000}, {TOPLEFT, TOPLEFT}, {MFL.savedVars.mainFramePosition[1], MFL.savedVars.mainFramePosition[2]}, false)
	mf:SetMovable(true)
    mf:SetClampedToScreen(true)
	mf:SetDrawLayer(0)
    mf:SetMouseEnabled(true)
    mf:SetHandler("OnMouseUp", function() MFL.UI.StopMovingOrResizing() end)
	
	mf:SetHandler("OnMouseWheel",function(self, delta)
		MFL.UI.MainFrame.offsetIndex = MFL.UI.MainFrame.offsetIndex - delta
		local playerCount = 0
		--How many players were showing.
		if(MFL.savedVars.showOffline == true) then
			--Display offline players, making our players to show count increase.
			playerCount = #MFL.PlayerList.Sorted
			else
			--Display only online players.
			playerCount = #MFL.PlayerList.Online
		end
		
		--Max range.
		if( MFL.UI.MainFrame.offsetIndex > (playerCount - MFL.savedVars.listSize + 1 ) ) then
			MFL.UI.MainFrame.offsetIndex = MFL.UI.MainFrame.offsetIndex + delta --Reverse the delta.
		end
		
		--Min range.
		if(MFL.UI.MainFrame.offsetIndex < 1) then
			MFL.UI.MainFrame.offsetIndex = 1  --Keep index in range.
		end
		
		--Force update friend list
		MFL.Update(true)
	end)
	
	--Button list control creation.
	local anchor = mf
	mf.btnList = {}
	for i = 1, MFL.savedVars.listSize, 1 do
		--(name, parent, dimensions, anchors, offsets, state, font, align, color, pressed, mouseover, isHidden)
		local btn = LibUI:CreateButton(MFL.name .. "_BTNLIST_" .. i, mf, {700, 100}, {TOPLEFT, TOPLEFT}, {0, 0}, nil, nil, nil, nil, nil, nil, false)
		btn:SetFont(MFL.savedVars.mainFrameFont)
		btn:SetDrawLayer(1)
		btn:SetText("@MeanMisterMusta")
		if MFL.savedVars.mainFrameFontAlign == "LEFT" then
			btn:SetHorizontalAlignment(0)
		elseif MFL.savedVars.mainFrameFontAlign == "CENTER" then
			btn:SetHorizontalAlignment(1)
		elseif MFL.savedVars.mainFrameFontAlign == "RIGHT" then
			btn:SetHorizontalAlignment(2)
		end
		
		btn:SetMouseOverFontColor(1.0, 1.0, 0.0, 1.0)
		btn:SetNormalFontColor(0.0, 0.6, 0.8, 0.95)
		
		--Set the dimensions of the button based on the font width/height.
		btn:SetDimensions(btn:GetLabelControl():GetTextWidth(), btn:GetLabelControl():GetFontHeight())
		btn:GetLabelControl():SetScale(0.90)
		btn:SetHandler("OnMouseUp", function() 
			MFL.OnFriendClicked(btn:GetLabelControl():GetText()) 
		end)
		
		btn:SetText("")
		btn:SetHidden(false)
		if i == 1 then
			btn:SetAnchor(TOPLEFT, anchor, TOPLEFT, 0, 0)
		else
			btn:SetAnchor(TOPLEFT, anchor, BOTTOMLEFT, 0, 0)
		end
		anchor = btn
		mf.btnList[i] = btn
	end
	
	mf:SetDimensions(mf.btnList[1]:GetWidth(), mf.btnList[1]:GetHeight() * MFL.savedVars.listSize)
	--mf.backdrop:SetDimensions(mf.btnList[1]:GetWidth(), mf.btnList[1]:GetHeight() * MFL.savedVars.listSize)
	mf.backdrop = LibUI:CreateBackdropFromVirtual(nil, mf, MFL.savedVars.skin)
	mf.backdrop:SetAlpha(MFL.savedVars.mainFrameAlpha / 100)
	
	mf:SetScale(MFL.savedVars.mainFrameScale / 100)
	
	--Create label to show when frame is movable.
	local labelMoveMe = LibUI:CreateLabel(MFL.name .. "_label", mf, {mf:GetWidth(), mf:GetHeight()}, {CENTER, CENTER}, {0, 0}, nil, nil, nil, "MiniFriendList \n Move me!", true)
	
	
	--If frame is movable, show the label.
	if MFL.savedVars.mainFrameMovable == true then
		labelMoveMe:SetHidden(false)
	else
		labelMoveMe:SetHidden(true)
	end
	
	mf.labelMoveMe = labelMoveMe
	MFL.UI.MainFrame.top = mf
end

function MFL.UI.MainFrame.Update()
	--See if we need to make frame movable.
	if MFL.savedVars.mainFrameMovable == true then
		--Make frame movable.
		for i = 1, MFL.savedVars.listSize, 1 do
			MFL.UI.MainFrame.top.btnList[i]:SetHidden(true)
		end
	else
		--Make frame non-movable.
		for i = 1, MFL.savedVars.listSize, 1 do
			MFL.UI.MainFrame.top.btnList[i]:SetHidden(false)
			MFL.UI.MainFrame.top.btnList[i]:SetText("")
		end
	end
	
	--Get the current offset index.
	local offset = MFL.UI.MainFrame.offsetIndex
	local btnLineIndex = 0
	
	--Loop through buttons and update text controls.
	if(MFL.savedVars.showOffline == true) then
		--Display offline players.		
		for i = offset, MFL.savedVars.listSize - 1 + offset, 1 do
			--Break early because total players is less than list size.
			if i > #MFL.PlayerList.Sorted then 
				break
			end
			btnLineIndex = btnLineIndex + 1
			
			if MFL.PlayerList.Sorted[i]["playerStatus"] == 1 then
				--Player Online.
				MFL.UI.MainFrame.top.btnList[btnLineIndex]:SetNormalFontColor(0.0, 0.6, 0.8, 0.95)
			else
				--Player Offline
				MFL.UI.MainFrame.top.btnList[btnLineIndex]:SetNormalFontColor(0.4, 0.4, 0.4, 0.9)
			end
			MFL.UI.MainFrame.top.btnList[btnLineIndex]:SetText(MFL.PlayerList.Sorted[i]["displayName"])
		end
	else
		--Display online players.
		for i = offset, MFL.savedVars.listSize - 1 + offset, 1 do
			--Break early because # online is less than list size.
			if i > #MFL.PlayerList.Online then 
				break
			end
			btnLineIndex = btnLineIndex + 1
			MFL.UI.MainFrame.top.btnList[btnLineIndex]:SetText(MFL.PlayerList.Online[i]["displayName"])
			MFL.UI.MainFrame.top.btnList[btnLineIndex]:SetNormalFontColor(0.0, 0.6, 0.8, 0.95)
		end
	end
end